#!/bin/bash

# This script is designed to update and publish a chrome extension
# that already exists in the Chrome Web Store. It also depends on
# OAuth 2.0 credentials and a refresh token.
#


# Configuration variables
# =======================

# The path to the OAuth 2.0 credentials.
# See: https://developer.chrome.com/webstore/using_webstore_api#beforeyoubegin
CLIENT_ID=$CHROME_STORE_CLIENT_ID
CLIENT_SECRET=$CHROME_STORE_CLIENT_SECRET
CODE=$CHROME_STORE_CODE
# This identifies which chrome extension will be updated
APP_ID=$CHROME_APP_ID

FILE_NAME=wallet-extension.zip


# Implementation
# ==============
# NOTE: We pass in -s so that curl doesn't print out sensitive api key material to datadog

function integrity_check() {
  echo "Getting sha256 of dist/*..."
  EXTENSION_SHA256=`openssl dgst -sha256 dist/* | openssl dgst -sha256` 
  echo "Got sha256 [${EXTENSION_SHA256}]"
}

function upload_to_dropbox() {
 # Upload wallet-extension.zip to Dropbox temporarily
 echo "Uploading $FILE_NAME to DropBox"
   curl -X POST https://content.dropboxapi.com/2/files/upload \
 --header "Authorization: Bearer $DROPBOX_API_KEY" \
 --header "Dropbox-API-Arg: {\"path\": \"/extension/$FILE_NAME\",\"mode\": \"add\",\"autorename\": true,\"mute\": false}" \
 --header "Content-Type: application/octet-stream" \
 --data-binary @$FILE_NAME
}

function get_access_token() {
  ACCESS_TOKEN=`curl "https://accounts.google.com/o/oauth2/token" -s -d \
  "client_id=${CLIENT_ID}&client_secret=${CLIENT_SECRET}&code=${CODE}&grant_type=authorization_code&redirect_uri=urn:ietf:wg:oauth:2.0:oob" | jq -r ".access_token"`
}

function upload() {
  curl \
  -H "Authorization:Bearer ${ACCESS_TOKEN}" \
  -H "x-goog-api-version:2" \
  -X PUT \
  -T ${FILE_NAME} \
  -v "https://www.googleapis.com/upload/chromewebstore/v1.1/items/${APP_ID}" > /dev/null 2>&1
}

#Temporary solution to be able to manually release the extension
# 1. Use codeflow to build the wallet-extension.zip file off of master (can provide evidence of that)
# 2. The codeflow build echo's out the sha256 of the decompressed zip folder that it built (openssl dgst -sha256 dist/* | openssl dgst -sha256)
# 3. Upload the zip file to the chrome extension store
# 4. The chrome extension store signs the zip file and generates a .crx file
# 5. Download the .crx file & unzip it (i.e. mkdir tmp && cd tmp && unzip foo.crx) to dist/
# 6. Remove omitting _metadata folder (this folder is added by chrome extension signing)
# 7. Get the sha256 of the decompressed zip folder that was downloaded from chrome extension store ((openssl dgst -sha256 dist/* | openssl dgst -sha256)
# 8. Verify that the output from 7 matches the output from codeflow at step 2
integrity_check
upload_to_dropbox

#Long term solution for releasing the extensin (upload to chrome extension store)
get_access_token
upload
