import React from 'react';
import { render, screen } from '@testing-library/react';

import manifestJson from '../../public/manifest.json';
import packageJson from '../../package.json';

import {
  ParentRequestEthereumAccounts,
  Connected,
  RequestEthereumAccounts,
} from '../util/Pubsub';

import App from '../App';
import { act } from 'react-dom/test-utils';

describe('Integrity checks', () => {
  it('manifest.json and package.json versions should match', () => {
    const { version: manifestJsonVersion } = manifestJson;
    const { version: packageJsonVersion } = packageJson;

    expect(packageJsonVersion).toEqual(manifestJsonVersion);
  });
});

/**
 * Note: The Pubsub path of App.tsx is not tested here as it's difficult to mock
 * the Pubsub results along with the Constructor checks
 */
describe('App state checks', () => {
  it('Should render connected state', () => {
    render(
      <App
        initialAppState={new Connected()}
      />
    );
    expect(screen.getByTestId('disconnect-button')).toBeInTheDocument();
    return act(() => Promise.resolve())
  });

  it('Should render connection request state', () => {
    const initialAppState = new ParentRequestEthereumAccounts(
      'walletLinkUrl',
      'sessionid',
      'sessionsecret',
      'version'
    );

    render(
      <App
        initialAppState={initialAppState}
      />
    );
    expect(screen.getByTestId('qr-container')).toBeInTheDocument();
    return act(() => Promise.resolve())
  });

  it('Should render request ethereum accounts state', () => {
    const initialAppState = new RequestEthereumAccounts(
      'eventid',
      'dappname',
      'dapplogourl',
      'dapplogourlalt',
      'https://dappurl.com',
      'sessionid',
      'sessionsecret'
    );

    render(
      <App
        initialAppState={initialAppState}
      />
    );
    expect(screen.getByTestId('allow-authorize-button')).toBeInTheDocument();
    return act(() => Promise.resolve())
  });
});
