import React, { FC } from 'react';
import { css } from 'linaria';
import { styled } from 'linaria/react';
import { Icon } from '@cbhq/cds-web/icons/Icon';
import { Button, ButtonGroup } from '@cbhq/cds-web/buttons';
import { useIntl } from 'react-intl';

const baseContainer = css`
  background-color: var(--background-alternate);
  display: flex;
  flex-direction: column;
`;

const IconContainer = styled.div`
  display: flex;
  justify-content: center;
  align-items: center;
  flex-grow: 1;
  height: 347px;
  color: rgb(var(--orange20));

  /* Hack for increasing the size of a CDS Icon */
  & > div {
    zoom: 3.5;
  }
`;

const buttonContainer = css`
  height: 174px;
  position: relative;
  background-color: var(--background);
  border-top-left-radius: 16px;
  border-top-right-radius: 16px;
  box-shadow: 0px 0px 8px rgba(0, 0, 0, 0.04), 0px 16px 24px rgba(0, 0, 0, 0.06);
`;

const buttonPosition = css`
  margin: 70px 24px 0 24px;
`;

const errorText = css`
  font-size: 20px;
  position: relative;
  margin-left: 24px;
  top: 34px;
`;

type AuthorizationErrorProps = {
  resetError: () => void;
};

const AuthorizationError: FC<AuthorizationErrorProps> = props => {
  const { resetError } = props;
  const intl = useIntl();

  return (
    <div className={baseContainer}>
      <IconContainer>
        <Icon name="error" size="l" color="currentColor" />
      </IconContainer>

      <div className={buttonContainer}>
        <div className={errorText}>
          {intl.formatMessage({
            id: 'connectionFailedMessage',
            description: 'Connection failed error status text',
            defaultMessage: 'Connection failed',
          })}
        </div>
        <div className={buttonPosition}>
          <ButtonGroup
            block
            accessibilityLabel={intl.formatMessage({
              id: 'tryAgainButtonGroup',
              description: 'Button group accessibility label',
              defaultMessage: 'Action buttons'
            })}
          >
            <Button type="button" variant="primary" onPress={resetError} data-testid="try-again">
              {intl.formatMessage({
                id: 'tryAgainButton',
                description: 'Action button text',
                defaultMessage: 'Try again',
              })}
            </Button>
          </ButtonGroup>
        </div>
      </div>
    </div>
  );
};

export default AuthorizationError;
