import React, { FC, useEffect, useState } from 'react';
import { Router, Route, Switch } from 'react-router-dom';
import { MemoryHistory, UnregisterCallback } from 'history';

import NavigationHistory from '../../util/NavigationHistory';
import Navigation from '../navigation/Navigation';
import Portfolio from '../portfolio/Portfolio';
import Settings from '../settings/Settings';
import log from '../../util/log';

type LoggedInHomeProps = {
  username: string;
};

const LoggedInHome: FC<LoggedInHomeProps> = () => {
  const [history, setHistory] = useState<MemoryHistory>();
  const navigationHistory = new NavigationHistory();
  let unlistenHistory: UnregisterCallback;

  useEffect(() => {
    navigationHistory
      .init()
      .then(() => {
        const memoryHistory = navigationHistory.getHistory();

        unlistenHistory = memoryHistory.listen(() => {
          navigationHistory.setHistoryInStorage(memoryHistory).catch(err => {
            // Do nothing, worst case user won't be continuing where they left off.
            log('LoggedInHome: Could not set History in storage', err);
          });
        });

        setHistory(memoryHistory);
      })
      .catch(err => {
        // Do nothing, worst case user won't be continuing where they left off.
        log('LoggedInHome: Could not initialize NavigationHistory', err);
      });

    return function cleanup() {
      unlistenHistory();
    };
  }, []);

  if (!history) {
    return <div>Test</div>;
  }

  return (
    <Router history={history}>
      <div>
        <Navigation />
        <div id="route-container">
          <Switch>
            <Route path="/" component={Portfolio} exact />
            <Route path="/portfolio" component={Portfolio} exact />
            <Route path="/settings" component={Settings} exact />
          </Switch>
        </div>
      </div>
    </Router>
  );
};

export default LoggedInHome;
