// Copyright (c) 2018-2020 WalletLink.org <https://www.walletlink.org/>
// Copyright (c) 2018-2020 Coinbase, Inc. <https://www.coinbase.com/>
// Licensed under the Apache License, version 2.0

import React from 'react';
import QRCodeSVG from 'walletlink/src/vendor-js/qrcode-svg/index';
import { Buffer } from 'buffer';
import { css } from 'linaria';
import QRLogoimg from '../../assets/QRLogo';

export interface QRCodeProps {
  content: string;
  width?: number;
  height?: number;
  fgColor?: string;
  bgColor?: string;
}
const qrCodeWrapper = css`
  left: 14.43%;
  right: 14.43%;
  top: 8.21%;
  bottom: 51.29%;
  border-radius: 0px;
  margin: 18.72px;
  width: 85%;
  height: 80%;
`;

const QRCode: React.FC<QRCodeProps> = props => {
  const [svg, setSvg] = React.useState('');
  React.useEffect(() => {
    const qrcode = new QRCodeSVG({
      content: props.content,
      background: props.bgColor || '#ffffff',
      color: props.fgColor || '#000000',
      container: 'svg',
      ecl: 'Q',
      width: props.width ?? 240,
      height: props.height ?? 240,
      padding: 0,
      join: true,
      image: {
        svg: QRLogoimg,
        width: 45,
        height: 45,
      },
    });
    const base64 = Buffer.from(qrcode.svg(), 'utf8').toString('base64');
    setSvg(`data:image/svg+xml;base64,${base64}`);
  });
  return svg ? <img className={qrCodeWrapper} src={svg} alt="QR Code" /> : null;
};

export default QRCode;
