import React from 'react';
import { act, render, screen, waitFor } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import ConnectionRequest from '../ConnectionRequest';
import { ParentRequestEthereumAccounts } from '../../../util/Pubsub';

describe('Connection Request', () => {
  const options = new ParentRequestEthereumAccounts(
    'walletLinkUrl',
    'sessionid',
    'sessionsecret',
    'version'
  );

  it('Should render', async () => {
    render (
      <ConnectionRequest
        options={options}
        fullScreen={false}
      />
    );

    await waitFor(() => {
      expect(screen.queryByTestId('connection-timeout-prompt')).toBeNull();
      expect(screen.getByTestId('qr-container')).toBeInTheDocument();
    });
  });

  it('Should render prompt after timeout', async () => {
    // Mock setTimeout timer
    jest.useFakeTimers();

    render (
      <ConnectionRequest
        options={options}
        fullScreen={false}
      />
    );

    act(() => {
      // Timer in the test is set to fire at 60 * 1000, so we increment time by a greater value
      jest.advanceTimersByTime(60 * 1001);
    });

    // Reset timers
    jest.runOnlyPendingTimers();
    jest.useRealTimers();

    await waitFor(() => {
      expect(screen.queryByTestId('connection-timeout-prompt')).toBeInTheDocument();
    });
  });

  it('Should open links when clicked', () => {
    render (
      <ConnectionRequest
        options={options}
        fullScreen={false}
      />
    );

    userEvent.click(screen.getByTestId('footer-link'));
    expect(chrome.tabs.create).toBeCalledWith({ url: 'home.html' });
    userEvent.click(screen.getByTestId('tooltip-link'));
    expect(chrome.tabs.create).toBeCalledWith({ url: 'home.html' });
  });
});
