import React from 'react';
import { render, screen } from '@testing-library/react';
import LoggedInHome from '../LoggedInHome';

const mockListener = jest.fn(callback => {
  callback({
    pathname: '/',
    key: '1415gg',
  });

  return jest.fn();
});

jest.mock('history');
jest.mock('../../../util/NavigationHistory', () => {
  return function () {
    return {
      init: jest.fn(() => {
        return Promise.resolve();
      }),
      getHistory: jest.fn(() => {
        const memoryHistory = {
          location: {
            pathname: '/',
            key: '1415gg',
          },
          entries: [
            {
              pathname: '/',
              key: '1415gg',
            },
          ],
          index: 0,
          length: 1,
          listen: jest.fn(mockListener),
        };

        return memoryHistory;
      }),
      setHistoryInStorage: jest.fn(() => {
        return Promise.resolve();
      }),
    };
  };
});

describe('LoggedInHome', () => {
  beforeAll(() => {
    jest.clearAllMocks();
  });

  it('Should render navigation with portfolio component', async () => {
    render(
      <LoggedInHome
        username="test1"
      />
    );

    expect(await screen.findByTestId('primary-navigation')).toBeInTheDocument();
    expect(await screen.findByTestId('portfolio-component')).toBeInTheDocument();
  });

  it('Should render navigation with settings component', async () => {
    mockListener.mockImplementation(callback => {
      callback({
        pathname: '/settings',
        key: '1415gg',
      });

      return jest.fn();
    });

    render(
      <LoggedInHome
        username="test1"
      />
    );

    expect(await screen.findByTestId('primary-navigation')).toBeInTheDocument();
    expect(await screen.findByTestId('settings-component')).toBeInTheDocument();
  });
});
