import * as React from 'react';
import { shouldReport, reportError } from '../../init/reportError';
import { ErrorFallbackView } from "./FallbackErrorView";

type Props = {
  children: React.ReactNode;
};

type State = {
  error: Error | null;
  errorHash: string | null;
};
export class ErrorBoundary extends React.Component<Props, State> {
  constructor(props:any) {
    super(props);
    this.state = {error: null, errorHash: null}
  }

  componentDidCatch(error: Error, errorInfo: React.ErrorInfo) {
    try {
      if (shouldReport(error)) {
        const { errorHash } = reportError({
          error,
          errorInfo,
        });
        this.setState({ errorHash: errorHash ?? null , error});
      }
    } catch (reportingError) {
      // eslint-disable-next-line no-console
      console.error('Error reporting error!!!!', reportingError);
    }
  }

  handleDismiss = () => {
    this.setState({ error: null });
    window.close();
  };

  render() {
    const { error, errorHash } = this.state;

    if (!error) {
      return this.props.children;
    }
    return (<div>
      Something went wrong
      <button onClick={this.handleDismiss}>Dismiss</button>
    </div>);
  }
}
