import React, { FC } from 'react';
import { styled } from 'linaria/react';
import { useIntl } from 'react-intl';
import { Link, useLocation } from 'react-router-dom';
import { Icon } from '@cbhq/cds-web/icons/Icon';

const NavContainer = styled.div`
  display: flex;
  justify-content: space-between;
  padding: 20px 90px 20px 90px;

  a {
    text-decoration: none;
  }
`;

type NavigationProps = Record<string, never>;

const Navigation: FC<NavigationProps> = () => {
  const intl = useIntl();
  const location = useLocation();

  return (
    <nav data-testid="primary-navigation">
      <NavContainer>
        <div>
          <Link
            to="/portfolio"
            title={intl.formatMessage({
              id: 'portfolioIconLinkLabel',
              description: 'Icon hover label',
              defaultMessage: 'Assets',
            })}
            data-testid="portfolio-navigation-link"
          >
            <Icon
              name="chartPie"
              size="s"
              color={location.pathname === '/portfolio' ? 'primary' : 'foregroundMuted'}
            />
          </Link>
        </div>
        <div>
          <Link
            to="/settings"
            title={intl.formatMessage({
              id: 'gearIconLinkLabel',
              description: 'Icon hover label',
              defaultMessage: 'Settings',
            })}
            data-testid="settings-navigation-link"
          >
            <Icon
              name="gear"
              size="s"
              color={location.pathname === '/settings' ? 'primary' : 'foregroundMuted'}
            />
          </Link>
        </div>
      </NavContainer>
    </nav>
  );
};

export default Navigation;
