import { css } from 'linaria';
import React, { useState } from 'react';
import { useIntl } from 'react-intl';
import manifest from '../../../public/manifest.json';

const Version = () => {
  const intl = useIntl();
  const { version } = manifest;

  const versionText = intl.formatMessage({
    id: 'welcomeFooterVersion',
    description: 'Footer app version',
    defaultMessage: 'Version',
  });

  const versionTextExpanded = intl.formatMessage(
    {
      id: 'welcomeFooterVersionExpanded',
      description: 'Footer app expanded version on click',
      defaultMessage: 'Version: {appVersion}',
    },
    {
      appVersion: version,
    }
  );

  const [text, setText] = useState(versionText);

  return (
    <a style={{ cursor: 'pointer' }} onClick={() => setText(versionTextExpanded)}>
      {text}
    </a>
  );
};

const container = css`
  margin-top: 24px;
  background: rgb(var(--gray0));
  opacity: 0.8;
  text-align: center;
  backdrop-filter: blur(40px);
  border-radius: 8px;
  padding: 16px;
`;

const horizontalList = css`
  font-size: 12px;
  line-height: 16px;
  width: fit-content;
  color: rgb(var(--gray60));
  margin: auto;
  display: flex;
  flex-direction: row;
`;

const linkStyle = css`
  text-decoration: none;
  font-size: 12px;
  line-height: 16px;
  color: rgb(var(--gray60));
`;

const FooterLink = (props: { text: string; url: string }) => {
  return (
    <a target="_blank" rel="noopener noreferrer" className={linkStyle} href={props.url}>
      <div>{props.text}</div>
    </a>
  );
};

export const Footer = () => {
  const intl = useIntl();

  return (
    <div className={container}>
      <div className={horizontalList}>
        <FooterLink
          text={intl.formatMessage({
            id: 'welcomeFooterPrivacy',
            description: 'Footer privacy link',
            defaultMessage: 'Privacy',
          })}
          url="https://wallet.coinbase.com/privacy-policy"
        />
        <div>&nbsp;•&nbsp;</div>
        <FooterLink
          text={intl.formatMessage({
            id: 'welcomeFooterTermsOfUse',
            description: 'Footer terms of use link',
            defaultMessage: 'Terms Of Use',
          })}
          url="https://wallet.coinbase.com/terms-of-service#"
        />
        <div>&nbsp;•&nbsp;</div>
        <FooterLink
          text={intl.formatMessage({
            id: 'welcomeFooterAttributions',
            description: 'Footer attributions link',
            defaultMessage: 'Attributions',
          })}
          url="https://github.com/walletlink/walletlink#attributions"
        />
        <div>&nbsp;•&nbsp;</div>
        <FooterLink
          text={intl.formatMessage({
            id: 'welcomeFooterFaq',
            description: 'Footer FAQ link',
            defaultMessage: 'FAQ',
          })}
          url="https://wallet.coinbase.com/faq/"
        />
        <div>&nbsp;•&nbsp;</div>
        <Version />
      </div>
    </div>
  );
};
