import { css } from 'linaria';
import * as React from 'react';
import { useIntl } from 'react-intl';
import walletIcon from '../../assets/logo-round-no-border.svg';
import extensionsIcon from '!!file-loader!../../assets/chrome-extensions-icon.png';

const container = css`
  margin-top: 32px;
  background-color: var(--background);
  opacity: 0.8;
  backdrop-filter: blur(40px);
  border-radius: 8px;
  padding: 16px;
`;

const headline = css`
  font-size: 16px;
  line-height: 24px;
  font-weight: 500;
  color: rgb(var(--gray60));
`;

const listContainer = css`
  margin-top: 0;
  margin-bottom: 0;
  list-style: none;
  position: relative;
  padding-left: 24px;
  counter-reset: getting-started-count;

  & > li {
    font-size: 16px;
    line-height: 24px;
    color: rgb(var(--gray60));
    margin-top: 20px;
    counter-increment: getting-started-count;
  }

  & > li::before {
    content: counter(getting-started-count);
    position: absolute;
    left: 0;
    color: rgb(var(--gray60));
  }

  & > li > img {
    display: inline-block;
    width: 20px;
    height: 20px;
    margin-left: 4px;
    margin-right: 4px;
    vertical-align: sub;
  }

  & > li > a {
    text-decoration: none;
    color: rgb(var(--blue50));
  }
`;

const puzzleIcon = css`
  @media (prefers-color-scheme: light) {
    filter: invert(100%);
  }
`;

export const GettingStarted = () => {
  const intl = useIntl();

  return (
    <div className={container}>
      <div className={headline}>
        {intl.formatMessage({
          id: 'gettingStartedTitle',
          description: 'Getting started title',
          defaultMessage: 'Getting started',
        })}
      </div>
      <ol className={listContainer}>
        <li>
          {intl.formatMessage(
            {
              id: 'gettingStartedWalletInstructionsStep1',
              description: 'Instructions for using wallet - step 1',
              defaultMessage: 'Click the {walletLogo} Wallet logo at the top right of your browser, or click {chromeExtensionIcon} to find the Wallet extension in the Chrome extensions list.',
            },
            {
              walletLogo: <img src={walletIcon} />,
              chromeExtensionIcon: <img className={puzzleIcon} src={extensionsIcon} />,
            }
          )}
        </li>
        <li>
          {intl.formatMessage({
            id: 'gettingStartedWalletInstructionsStep2',
            description: 'Instructions for using wallet - step 2',
            defaultMessage: "Scan the QR code with your Wallet mobile app to connect. If you can't connect, make sure you're using the latest version of the Wallet app.",
          })}
        </li>
        <li>
          {intl.formatMessage({
            id: 'gettingStartedWalletInstructionsStep3',
            description: 'Instructions for using wallet - step 3',
            defaultMessage: "Close this tab after you're connected.",
          })}
        </li>
        <li>
          {intl.formatMessage(
            {
              id: 'gettingStartedWalletInstructionsStep4',
              description: 'Instructions for using wallet - step 4',
              defaultMessage: 'Visit a {dappUrl} and begin making transactions! 🎉',
            },
            {
              dappUrl: <a href="https://wallet.coinbase.com/start/?ref=extensionlauncher" target="_blank" rel="noopener noreferrer">dapp</a>
            }
          )}
        </li>
      </ol>
    </div>
  );
};
