import { css } from 'linaria';
import * as React from 'react';
import { Icon } from '@cbhq/cds-web/icons/Icon';
import { IconName } from '@cbhq/cds-web';

const container = css`
  display: flex;
  flex-direction: row;
  cursor: pointer;
  width: fit-content;
  text-decoration: none;
`;

const icon = css`
  width: 16px;
  height: 16px;
`;

const text = css`
  font-size: 13px;
  line-height: 16px;
  font-weight: 500;
  margin-left: 8px;
  color: rgb(var(--gray100));
`;

type LinkWithIconProps = {
  text: string;
  url: string;
  name?: IconName;
  icon?: string;
};

export const LinkWithIcon = (props: LinkWithIconProps) => {
  // Use CDS icon if a name is given instead of "icon" prop
  if (props.name) {
    return (
      <a className={container} href={props.url} target="_blank" rel="noopener noreferrer">
        <Icon name={props.name} size="s" color="foreground" />
        <div className={text}>{props.text}</div>
      </a>
    );
  }

  return (
    <a className={container} href={props.url} target="_blank" rel="noopener noreferrer">
      <img src={props.icon} className={icon} />
      <div className={text}>{props.text}</div>
    </a>
  );
};
