import { css } from 'linaria';
import * as React from 'react';
import { useIntl } from 'react-intl';
import walletLogo from '../../assets/logo-round-no-border.svg';
import { LinkWithIcon } from './LinkWithIcon';
import { GettingStarted } from './GettingStarted';
import { Footer } from './Footer';

const contentWidth = 430;
const contentPadding = 32;

const parentContainer = css`
  margin: auto;
  padding-left: ${contentPadding}px;
  padding-right: ${contentPadding}px;
`;

const container = css`
  --width: ${contentWidth}px;
  --lmargin: calc((100vw / 3) - (var(--width) / 2));
  width: var(--width);
  margin-left: max(0px, var(--lmargin));

  @media (max-width: ${contentWidth + 2 * contentPadding + 2 * 8 /*body padding*/}px) {
    width: 100%;
  }
`;

const logo = css`
  width: 56px;
  height: 56px;
  margin-top: 60px;
`;

const titleText = css`
  font-size: 28px;
  color: rgb(var(--gray100));
  font-weight: 500;
  margin-top: 16px;
  margin-bottom: 0;
`;

const subtitleText = css`
  font-size: 20px;
  line-height: 28px;
  font-weight: 500;
  color: rgb(var(--gray50));
  margin-top: 0;
`;

const descriptionText = css`
  font-size: 16px;
  line-height: 24px;
  color: rgb(var(--gray100));
  margin-top: 26px;
  margin-bottom: 48px;
`;

const backgroundContainer = css`
  background-color: var(--background);
  width: 100vw;
  height: 100vh;
  overflow: hidden;
  position: fixed;
  top: 0;
  left: 0;
  z-index: -1;
`;

const circleBackground = css`
  --lpos: calc((100vw / 3) - ${contentWidth}px);
  height: max(200vh, 175vw);
  width: max(200vh, 175vw);
  top: 10vh;
  left: max(calc(${contentWidth}px / 2), var(--lpos));
  border-radius: 50%;
  filter: blur(20px);
  z-index: -1;
  display: block;
  position: absolute;
  background-color: rgb(var(--blue50));
`;

export const Welcome = () => {
  const intl = useIntl();

  return (
    <div className={parentContainer}>
      <div className={backgroundContainer}>
        <span className={circleBackground} />
      </div>
      <div className={container}>
        <img src={walletLogo} className={logo} />
        <h1 className={titleText}>
          {intl.formatMessage({
            id: 'welcomePageTitleText',
            description: 'Application title',
            defaultMessage: 'Coinbase Wallet'
          })}
        </h1>
        <h3 className={subtitleText}>
          {intl.formatMessage({
            id: 'welcomePageSubtitleText',
            description: 'Subtitle text (Chrome extension)',
            defaultMessage: 'Extension'
          })}
        </h3>
        <p className={descriptionText}>
          {intl.formatMessage({
            id: 'welcomePageWalletDescription',
            description: 'Wallet extension description',
            defaultMessage: 'Connect your Wallet mobile app to make crypto app transactions on desktop easier.'
          })}
        </p>
        <LinkWithIcon
          name="globe"
          text={intl.formatMessage({
            id: 'welcomePageLinkDescription',
            description: 'Linked description',
            defaultMessage: 'Learn more at wallet.coinbase.com'
          })}
          url="https://wallet.coinbase.com"
        />
        <GettingStarted />
        <Footer />
      </div>
    </div>
  );
};
