import { WalletLinkRelayEventManager } from 'walletlink/build/npm/dist/relay/WalletLinkRelayEventManager';
import { ScopedLocalStorage } from 'walletlink/build/npm/dist/lib/ScopedLocalStorage';
import { WalletLinkRelay } from 'walletlink/build/npm/dist/relay/WalletLinkRelay';
import { getFavicon } from 'walletlink/build/npm/dist/util';
import log from '../util/log';
import {
  WalletLinkInPageExtensionUI,
  WalletLinkInPageUIOptions,
} from './WalletLinkInPageExtensionUI';

const WALLETLINK_URL = 'https://www.walletlink.org';

function makeWalletLinkRelay(
  relayEventManager: WalletLinkRelayEventManager,
  storage: ScopedLocalStorage
): WalletLinkRelay {
  if (typeof relayEventManager === 'undefined') {
    throw new Error('Relay event manager undefined');
  }

  if (typeof storage === 'undefined') {
    throw new Error('Storage undefined');
  }

  log('Constructed wallet link relay');
  const walletLinkRelay = new WalletLinkRelay({
    walletLinkUrl: WALLETLINK_URL,
    version: '1',
    darkMode: false,
    walletLinkUIConstructor: options => {
      let newOptions: WalletLinkInPageUIOptions = {
        walletLinkUrl: options.walletLinkUrl,
        version: options.version,
        darkMode: options.darkMode,
        session: options.session,
        connected$: options.connected$,
        resetConnectionCallback: () => {
          walletLinkRelay.resetAndReload();
        },
      };

      return new WalletLinkInPageExtensionUI(newOptions);
    },
    storage: storage,
    relayEventManager: relayEventManager,
  });

  walletLinkRelay.setAppInfo(document.location.host, getFavicon());
  walletLinkRelay.attachUI();

  return walletLinkRelay;
}

//@ts-ignore
if (typeof window.walletLinkExtension === 'undefined') {
  throw new Error('Wallet link extension undefined');
}

//@ts-ignore
window.walletLinkRelay = makeWalletLinkRelay(
  //@ts-ignore
  window.walletLinkRequestProvider.relayEventManager,

  //@ts-ignore
  window.walletLinkRequestProvider.storage
);
