import { CurrencyCode } from './CurrencyCode';
import { Blockchain } from './Blockchain';

/**
 * Primary key = blockchain + code
 * Unique index = blockchain + code
 * Index = sortIndex
 */
export const schema =
  '[blockchainStr+codeStr],&[blockchainStr+codeStr],[sortIndex],codeStr,blockchainStr,sortIndex';
export class CryptoCurrency {
  public codeStr: string;
  public name: string;
  public decimals: bigint;
  public blockchainStr: string;
  public sortIndex: bigint;
  public imageURLStr?: string;

  constructor(
    code: CurrencyCode,
    name: string,
    decimals: bigint,
    blockchain: Blockchain,
    sortIndex: bigint,
    imageURLStr?: string
  ) {
    this.codeStr = code.rawValue;
    this.name = name;
    this.decimals = decimals;
    this.blockchainStr = blockchain.rawValue;
    this.sortIndex = sortIndex;
    this.imageURLStr = imageURLStr;
  }

  get code(): CurrencyCode {
    return new CurrencyCode(this.codeStr);
  }

  get blockchain(): Blockchain {
    return new Blockchain(this.blockchainStr);
  }

  imageURL(): URL | null {
    if (!this.imageURLStr) {
      return null;
    }

    return new URL(this.imageURLStr);
  }
}
