import { Blockchain } from './Blockchain';
import { CurrencyCode } from './CurrencyCode';
import { Network } from './Network';
import { WalletAddress } from './WalletAddress';

export class Wallet {
  id: string;
  primaryAddress: string;
  addresses: WalletAddress[];
  displayName: string;
  currencyCode: CurrencyCode;
  contractAddress?: string;
  imageURL?: URL;
  balance: bigint;
  decimals: bigint;
  blockchain: Blockchain;
  minimumBalance?: bigint;
  network: Network;
  selectedIndex?: bigint;

  constructor(
    primaryAddress: string,
    addresses: WalletAddress[],
    displayName: string,
    currencyCode: CurrencyCode,
    balance: bigint,
    decimals: bigint,
    blockchain: Blockchain,
    network: Network,
    contractAddress?: string,
    imageURL?: URL,
    minimumBalance?: bigint,
    selectedIndex?: bigint
  ) {
    this.id = Wallet.generateID(blockchain, currencyCode, network, contractAddress, selectedIndex);
    this.primaryAddress = primaryAddress;
    this.addresses = addresses;
    this.displayName = displayName;
    this.currencyCode = currencyCode;
    this.contractAddress = contractAddress;
    this.imageURL = imageURL;
    this.balance = balance;
    this.decimals = decimals;
    this.blockchain = blockchain;
    this.minimumBalance = minimumBalance;
    this.network = network;
    this.selectedIndex = selectedIndex;
  }

  private static generateID(
    blockchain: Blockchain,
    currencyCode: CurrencyCode,
    network: Network,
    contractAddress?: string,
    selectedIndex?: bigint
  ): string {
    return [
      blockchain.rawValue,
      currencyCode.rawValue,
      network.rawValue,
      contractAddress,
      selectedIndex?.toString(),
    ].join('/');
  }
}
