import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { HTTP } from '@http/HTTP';
import { HTTPResponse } from '@http/models/HTTPResponse';
import { HTTPService } from '@http/models/HTTPService';
import { CryptoCurrenciesDTO, CryptoCurrencyDTO } from '../dtos/CryptoCurrencyDTO';
import { CTokenInfoDTO, GetCTokenInfoDTO } from '../dtos/GetCTokenInfoDTO';
import { HTTPEthCall } from '@ethereum/extensions/HTTP+Ethereum';
import { ETHCallResponseDTO } from '@ethereum/dtos/ETHCallResponseDTO';

export class CompoundFinanceAPI {
  private infuraKey: string;
  private walletService: HTTPService;
  constructor(infuraKey: string, walletApiUrlString: string) {
    this.infuraKey = infuraKey;
    this.walletService = new HTTPService(walletApiUrlString);
  }

  getExchangeRate(contractAddress: string, chainID = 1n): Observable<bigint> {
    return HTTPEthCall.ethCall(
      this.infuraKey,
      chainID,
      'exchangeRateCurrent',
      contractAddress
    ).pipe(
      map((response: ETHCallResponseDTO) => {
        const result: string = response.result;
        const hexRate = result.startsWith('0x') ? result : `0x${result}`;
        return BigInt(hexRate);
      })
    );
  }

  getTokens(): Observable<CTokenInfoDTO[]> {
    const service = new HTTPService('https://compound.wallet.coinbase.com');
    return HTTP.get<GetCTokenInfoDTO>(service, '/api/v2/ctoken').pipe(
      map((response: HTTPResponse<GetCTokenInfoDTO>) => {
        return response.body.cToken;
      })
    );
  }

  getCryptoCurrencies(): Observable<CryptoCurrencyDTO[]> {
    return HTTP.get<CryptoCurrenciesDTO>(this.walletService, '/rpc/v2/getCryptoCurrencies').pipe(
      map((response: HTTPResponse<CryptoCurrenciesDTO>) => {
        return response.body.result.cryptoCurrencies;
      })
    );
  }
}
