import axios from 'axios';
import { CompoundFinanceAPI } from '../CompoundFinanceAPI';
import MockAdapter from 'axios-mock-adapter';

const mockedAxios = new MockAdapter(axios);

const compoundTokens = [
  {
    name: 'Bitcoin',
    symbol: 'BTC',
    token_address: 'contractAddress',
    underlying_symbol: 'underlyingCode',
    underlying_address: 'underlyingContractAddress',
  },
  {
    name: 'Ethereum',
    symbol: 'ETH',
    token_address: 'contractAddress2',
    underlying_symbol: 'underlyingCode2',
    underlying_address: 'underlyingContractAddress2',
  },
];

const cryptoCurrencies = [
  {
    name: 'Bitcoin',
    code: 'BTC',
    imageUrl: 'https://1.png',
    blockchain: 'btc',
    decimals: 8,
    marketCap: 758901722568.4563,
  },
  {
    name: 'Ethereum',
    code: 'ETH',
    imageUrl: 'https://2.png',
    blockchain: 'eth',
    decimals: 18,
    marketCap: 300249833368.14075,
  },
];

describe('Compound Finance API', () => {
  it('should return cTokens', () => {
    const compoundFinanceAPI = new CompoundFinanceAPI(
      'infuraKey',
      'https://api.wallet.coinbase.com'
    );

    mockedAxios
      .onGet('https://compound.wallet.coinbase.com/api/v2/ctoken')
      .reply(200, { cToken: compoundTokens });

    return compoundFinanceAPI
      .getTokens()
      .toPromise()
      .then(data => {
        expect(data.length).toEqual(compoundTokens.length);

        data.forEach((res, index) => {
          const resStr = JSON.stringify(res, (key, value) => {
            return typeof value === 'bigint' ? value.toString() : value;
          });

          const actualStr = JSON.stringify(compoundTokens[index], (key, value) => {
            return typeof value === 'bigint' ? value.toString() : value;
          });

          expect(resStr).toEqual(actualStr);
        });
      });
  });

  it('should return CryptoCurrencies', () => {
    const compoundFinanceAPI = new CompoundFinanceAPI(
      'infuraKey',
      'https://api.wallet.coinbase.com'
    );
    mockedAxios
      .onGet('https://api.wallet.coinbase.com/rpc/v2/getCryptoCurrencies')
      .reply(200, { result: { cryptoCurrencies } });

    return compoundFinanceAPI
      .getCryptoCurrencies()
      .toPromise()
      .then(data => {
        expect(data.length).toEqual(cryptoCurrencies.length);

        data.forEach((res, index) => {
          const resStr = JSON.stringify(res, (key, value) => {
            return typeof value === 'bigint' ? value.toString() : value;
          });

          const actualStr = JSON.stringify(cryptoCurrencies[index], (key, value) => {
            return typeof value === 'bigint' ? value.toString() : value;
          });

          expect(resStr).toEqual(actualStr);
        });
      });
  });
});
