import { Observable, Observer, OperatorFunction, Subscription } from 'rxjs';
import { flatMap } from 'rxjs/operators';

let subscribeOriginal = Observable.prototype.subscribe;

export function initDefaultErrorHandler() {
  Observable.prototype.subscribe = function (arg1: any, arg2?: any, arg3?: any): Subscription {
    subscribeOriginal.bind(this.source)
    let errorHandler = function (result: any) {
      if (typeof arg2 !== 'function') {
        if (process.env.NODE_ENV === 'production') {
          //TODO WALL-1530 add error logging to bugsnag
        } else {
          console.log("Caught unhandled exception")
          console.log(result);
        }
      } else {
        arg2(result);
      }
    };
    return subscribeOriginal.call(this, arg1, errorHandler, arg3);
  };
}

/**
 * Safe unwrap element. Note this will block the chain until a valid non-undefined value is available.
 *
 * @param T The element to unwrap
 *
 * @return The raw value [T] that has been unwrapped from a nullable
 */
export function unwrap<T>(): OperatorFunction<T | undefined, T> {
  return flatMap(value => {
    if (value) {
      return new Observable<T>(observer => {
        observer.next(value as T)
        observer.complete()
      })
    } else {
      return new Observable<T>(observer => observer.complete())
    }
  })
}
