import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { HTTP } from '@http/HTTP';
import { HTTPResponse } from '@http/models/HTTPResponse';
import { HTTPService } from '@http/models/HTTPService';
import { ETHCallResponseDTO } from '../dtos/ETHCallResponseDTO';
import { AbiInput } from 'web3-utils';
import { ERC20ContractError } from '../exceptions/ERC20ContractError';

const Web3EthAbi = require('web3-eth-abi');

type AbiParam = AbiInput & { value: string };

export class HTTPEthCall {
  static ethCall(
    infuraKey: string,
    chainID: bigint,
    method: string,
    toAddress: string,
    parameters?: AbiParam[],
    blockHeight?: bigint
  ): Observable<ETHCallResponseDTO> {
    const service = HTTPService.ethereum(chainID);
    if (service === undefined) {
      throw ERC20ContractError.unableToFindEthereumRPCURL;
    }

    const inputs: { type: string; name: string }[] = [];
    const values: string[] = [];
    parameters?.forEach(param => {
      inputs.push({
        type: param.type,
        name: param.name,
      });
      values.push(param.value.toString());
    });
    const encodedData = Web3EthAbi.encodeFunctionCall(
      {
        name: method,
        type: 'function',
        inputs: inputs,
      },
      values
    );

    return HTTP.post<ETHCallResponseDTO>(
      service,
      `/${infuraKey}`,
      new Map(
        Object.entries({
          jsonrpc: '2.0',
          id: 1,
          method: 'eth_call',
          params: [{ to: toAddress, data: encodedData }, blockHeight?.toString() ?? 'latest'],
        })
      )
    ).pipe(
      map((response: HTTPResponse<ETHCallResponseDTO>) => {
        return response.body;
      })
    );
  }
}
