import { HTTPRequestFailed } from "@http/errors/HTTPError";
import { RPCError } from "@http/errors/RPCError";
import { HTTPService } from "@http/models/HTTPService";
import { RPC } from "@http/RPC";
import axios from 'axios';

jest.mock('axios')
const mockedAxios = axios as jest.Mocked<typeof axios>;

interface FooInterface {
    foo: string
}

describe('rpc', () => {
  it('Should return valid response', () => {
      mockedAxios.get.mockResolvedValue({ data: { result: { foo: "bar"} }})

      return RPC.get<FooInterface>(
          new HTTPService("https://1.com"),
          "/foo"
      )
        .toPromise()
        .then(data => expect(data).toEqual({foo: "bar"}))
  });

  it('Should return http error', () => {
      mockedAxios.get.mockRejectedValueOnce( { response: { status: 404, data: "404 page not found" }})

    return RPC.get<FooInterface>(
      new HTTPService("https://1.com"),
      "/foo"
    )
      .toPromise()
      .then(data => fail("Shouldn't have received data"))
      .catch(error => expect(error).toBeInstanceOf(HTTPRequestFailed))
  })

  it('Should return rpc error', ()=> {
    mockedAxios.get.mockRejectedValueOnce( { response: { status: 404, data: { error : { name: "rpc error", message: "Got invalid params", code: "invalidParams" }}}})

    return RPC.get<FooInterface>(
      new HTTPService("https://1.com"),
      "/foo"
    )
      .toPromise()
      .then(data => fail("Shouldn't have received data"))
      .catch(error => expect(error).toBeInstanceOf(RPCError))
  })

});
