import { AxiosResponse } from 'axios';
import { RPCError } from './RPCError';

export class HTTPError implements Error {
  name: string;
  message: string;

  constructor(name: string, message: string) {
    this.name = name;
    this.message = message;
  }

  get asRPCError(): RPCError | undefined {
    if (this instanceof HTTPRequestFailed) {
      return this.parseError(this.data);
    }
    return undefined;
  }

  private parseError(data: any): RPCError | undefined {
    try {
      let error = data.error;

      if (typeof error === 'undefined') {
        return undefined;
      }

      let name = error.name;
      let message = error.message;
      let code = error.code;
      if (
        typeof name !== 'undefined' &&
        typeof message !== 'undefined' &&
        typeof code !== 'undefined'
      ) {
        return new RPCError(name, message, code);
      }

      return undefined;
    } catch {
      return undefined;
    }
  }
}

export class HTTPRequestFailed extends HTTPError {
  response: AxiosResponse;
  data: any;
  constructor(response: AxiosResponse, data: any) {
    super('HTTPRequestFailed', `Http request failed with ${response.status}`);
    this.response = response;
    this.data = data;
  }
}
