import { Storage } from '@store/interfaces/Storage';
import { StoreKey } from '@store/models/StoreKey';

export class LocalStorage implements Storage {
  private storageScope = 'CBStore.plaintext';
  static mappedPrototypes = new Map<String, any>()

  set<T>(key: StoreKey<T>, value?: T): void {
    if (!value) {
      localStorage.removeItem(this.scopedKey(key.name));
    }

    let jsonValue = JSON.stringify(value)
    localStorage.setItem(this.scopedKey(key.name), jsonValue);
  }

  get<T>(key: StoreKey<T>): T | undefined {
    const value = localStorage.getItem(this.scopedKey(key.name));
    if (!value) return undefined;

    let parsedValue = JSON.parse(value, (key, value) => {
      if (typeof value === 'string' && value.startsWith('bigint:')) {
        return BigInt(value.substr('bigint:'.length));
      } else {
        return value;
      }
    });

    let prototype = LocalStorage.mappedPrototypes.get(key.name)
    if (prototype) {
      let parsedValueWithClass = Object.create(prototype)
      Object.assign(parsedValueWithClass, parsedValue)
      return parsedValueWithClass
    }

    return parsedValue
  }

  destroy(): void {
    const prefix = this.scopedKey('');
    const keysToRemove: string[] = [];
    for (let i = 0; i < localStorage.length; i++) {
      const key = localStorage.key(i);
      if (typeof key === 'string' && key.startsWith(prefix)) {
        keysToRemove.push(key);
      }
    }

    keysToRemove.forEach(key => localStorage.removeItem(key));
  }

  private scopedKey(key: string): string {
    return `${this.storageScope}:${key}`;
  }
}
