export class AccessTokenError implements Error {
  name: string;
  message: string;

  private constructor(name: string, message: string) {
    this.name = name;
    this.message = message;
  }
  /**
   * Thrown when creating a nonce fails
   */
  static unableToCreateNonce = new AccessTokenError(
    'unableToCreateNonce',
    'Unable to create nonce'
  );

  /**
   * Thrown when user is unable to sign up for the wallet backend
   */
  static unableToCreateUser = new AccessTokenError('UnableToCreateUser', 'Unable to create user');

  /**
   * Thrown when the user is unable to sign in to our backend
   */
  static unableToCreateAccessToken = new AccessTokenError(
    'UnableToCreateAccessToken',
    'Unable to sign in'
  );

  /**
   * Thrown when refreshing the access token fails
   */
  static unableToRefreshAccessToken = new AccessTokenError(
    'UnableToRefreshAccessToken',
    'Unable to refresh access token'
  );

  /**  Thrown when Rpc does not have an authentication repository configured */
  static accessTokenManagerNotConfigured = new AccessTokenError(
    'AccessTokenManagerNotConfigured',
    'No authentication repository configured'
  ); 
}
