import { HTTPService } from '@http/models/HTTPService';
import { LocalStorage } from '@store/storages/LocalStorage';
import { MemoryStorage } from '@store/storages/MemoryStorage';
import axios from 'axios';
import MockAdapter from 'axios-mock-adapter';
import { AuthenticationAPI } from '../../apis/AuthenticationAPI';
import { AuthenticationRepository } from '../AuthenticationRepository';
import { CipherCore } from 'cipher-core';
import { Store } from '@store/Store';
import { WalletLinkProvider } from 'walletlink';

const mockedAxios = new MockAdapter(axios);
jest.mock('walletlink')
describe('authentication repository', () => {
  it('should create signed message', () => {
    mockedAxios
      .onPost('https://api.wallet.coinbase.com/rpc/v2/createNonce')
      .reply(200, { result: { nonce: '0' } });

    mockedAxios
      .onPost('https://api.wallet.coinbase.com/rpc/v2/createAccessToken', {
        nonce: "0",
        address: "0xAD013d72C1D8143Ff21ef79F407489ee724dFAe9",
        signature: "0xbf5290816345b086ffd5c472938decf2a3e09ad44144bec035ce677d51acb6632df6dd188bca72a892f87d1f73b0c9e094441506ca2f501539ee1c041a8c06871c"
      })
      .reply(200, {
        result: { token: 'accessToken', expiresIn: 'unused', refreshToken: 'refreshToken' },
      });

    const store = new Store(new LocalStorage(), new MemoryStorage());
    const cipherCore = new CipherCore({
      ethereum: {
        networks: {},
      },
    });

    const authRepository = new AuthenticationRepository(
      new AuthenticationAPI(new HTTPService('https://api.wallet.coinbase.com')),
      store,
      cipherCore,
      {} as WalletLinkProvider
    );

    return authRepository
      .signIn('mansion turn clock casual share weird thought only parent equip abuse track')
      .toPromise()
      .then(result => {
        expect(result.token).toEqual('accessToken');
        expect(result.refreshToken).toEqual('refreshToken');
      });
  });
});
