import { Observable } from 'rxjs';
import { map } from 'rxjs/operators';
import { CryptoCurrency } from '@blockchains/models/CryptoCurrency';
import { CryptoCurrencyDTO, asCryptoCurrency } from '@wallets/dtos/CryptoCurrencyDTO';
import { RPC } from '@http/RPC';
import { HTTPService } from '@http/models/HTTPService';

export class CryptoCurrencyAPI {
  private service: HTTPService;
  constructor(service: HTTPService) {
    this.service = service;
  }

  getCryptoCurrencies(chainId: BigInt): Observable<CryptoCurrency[]> {
    return RPC.get<CryptoCurrencyDTO>(
      this.service,
      '/rpc/v2/getCryptoCurrencies',
      false,
      new Map([['chainId', chainId.toString()]])
    ).pipe(
      map((currencies: CryptoCurrencyDTO) => {
        const sortedCurrencies = currencies.cryptoCurrencies;
        sortedCurrencies.sort((a, b) => {
          if (a.marketCap === b.marketCap) {
            return a.name
              .toLocaleLowerCase('en-US')
              .localeCompare(b.name.toLocaleLowerCase('en-US'));
          }

          return a.marketCap < b.marketCap ? 1 : -1;
        });

        return sortedCurrencies.map((currency, index) => asCryptoCurrency(currency, BigInt(index)));
      })
    );
  }
}
