import { HTTPService } from '@http/models/HTTPService';
import { CryptoCurrencyAPI } from '../CryptoCurrencyAPI';
import axios from 'axios';
import { CryptoCurrency } from '@blockchains/models/CryptoCurrency';
import { CurrencyCode } from '@blockchains/models/CurrencyCode';
import { Blockchain } from '@blockchains/models/Blockchain';

jest.mock('axios');
const mockedAxios = axios as jest.Mocked<typeof axios>;

describe('Crypto currency api', () => {
  it('Should parse valid response', () => {
    let api = new CryptoCurrencyAPI(new HTTPService('https://api.wallet.coinbase.com'));
    let cryptoCurrencies = [
      {
        name: 'Bitcoin',
        code: 'BTC',
        imageUrl: 'https://1.png',
        blockchain: 'btc',
        decimals: 8,
        marketCap: 758901722568.4563,
        swappable: false,
      },
      {
        name: 'Ethereum',
        code: 'ETH',
        imageUrl: 'https://2.png',
        blockchain: 'eth',
        decimals: 18,
        marketCap: 300249833368.14075,
        swappable: false,
      },
      {
        name: 'WETH',
        code: 'WETH',
        imageUrl: 'https://3.png',
        blockchain: 'eth',
        decimals: 18,
        marketCap: 300249833368.14075,
        swappable: true,
        contractAddress: '0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2',
      },
    ];

    let expectedCryptoCurrencies = [
      new CryptoCurrency(
        new CurrencyCode('BTC'),
        'Bitcoin',
        8n,
        new Blockchain('btc'),
        0n,
        'https://1.png'
      ),
      new CryptoCurrency(
        new CurrencyCode('ETH'),
        'Ethereum',
        18n,
        new Blockchain('eth'),
        1n,
        'https://2.png'
      ),
      new CryptoCurrency(
        new CurrencyCode('WETH'),
        'WETH',
        18n,
        new Blockchain('eth'),
        2n,
        'https://3.png'
      ),
    ];

    mockedAxios.get.mockResolvedValue({ data: { result: { cryptoCurrencies } } });

    return api
      .getCryptoCurrencies(BigInt(1))
      .toPromise()
      .then(data => {
        expect(data.length).toEqual(expectedCryptoCurrencies.length);
        data.forEach((res, index) => {
          let resStr = JSON.stringify(res, (key, value) => {
            return typeof value === 'bigint' ? value.toString() : value;
          });

          let actualStr = JSON.stringify(expectedCryptoCurrencies[index], (key, value) => {
            return typeof value === 'bigint' ? value.toString() : value;
          });

          expect(resStr).toEqual(actualStr);
        });
      });
  });
});
