import { CryptoCurrency } from '@blockchains/models/CryptoCurrency';
import { from, Observable } from 'rxjs';
import { map, single } from 'rxjs/operators';
import { CurrencyCode } from '@blockchains/models/CurrencyCode';
import { Dexie } from 'dexie';
import { Blockchain } from '@blockchains/models/Blockchain';

export class CryptoCurrencyDAO {
  table: Dexie.Table<CryptoCurrency, any>;
  constructor(table: Dexie.Table<CryptoCurrency, any>) {
    this.table = table;
  }

  saveCryptoCurrencies(cryptoCurrencies: CryptoCurrency[]): Observable<CryptoCurrency[]> {
    return from(this.table.bulkPut(cryptoCurrencies))
      .pipe(map(ev => cryptoCurrencies))
      .pipe(single());
  }

  getCryptoCurrencies(): Observable<CryptoCurrency[]> {
    return from(this.table.toArray()).pipe(single());
  }

  getSelectCryptoCurrencies(currencyCodes: CurrencyCode[]): Observable<CryptoCurrency[]> {
    const codes = currencyCodes.map(code => code.rawValue);
    return from(this.table.where('codeStr').anyOf(codes).toArray()).pipe(single());
  }
}
