import { Dexie } from 'dexie';
import { Blockchain } from '@blockchains/models/Blockchain';
import { CryptoCurrency, schema as CryptoCurrencySchema } from '@blockchains/models/CryptoCurrency';
import { CurrencyCode } from '@blockchains/models/CurrencyCode';
import {
  CompoundToken,
  schema as CompoundTokenSchema,
} from '@compoundfinance/models/CompoundToken';
import { ExchangeRate, schema as ExchangeRateSchema } from '@wallets/models/ExchangeRate';

export class WalletsDatabase extends Dexie {
  cryptoCurrencyTable?: Dexie.Table<CryptoCurrency, any>;
  compoundTokenTable?: Dexie.Table<CompoundToken, any>;
  exchangeRateTable?: Dexie.Table<ExchangeRate, any>;

  constructor() {
    super('Database');
    this.version(1).stores({
      cryptoCurrencyTable: CryptoCurrencySchema,
      compoundTokenTable: CompoundTokenSchema,
      exchangeRateTable: ExchangeRateSchema,
    });
    this.cryptoCurrencyTable?.mapToClass(CryptoCurrency);
    this.compoundTokenTable?.mapToClass(CompoundToken);
    this.exchangeRateTable?.mapToClass(ExchangeRate);
  }
}
