import { CryptoCurrency } from '@blockchains/models/CryptoCurrency';
import { CurrencyCode } from '@blockchains/models/CurrencyCode';
import { Blockchain } from '@blockchains/models/Blockchain';

// The json field that contains all cryptocurrency DTOs
export interface CryptoCurrencyDTO {
    /// The contained cryptocurrencies in the JSON response
    cryptoCurrencies: CryptoCurrencyEntryDTO[];
}

// A single element of a crypto currency DTO
interface CryptoCurrencyEntryDTO {
    /// Currency name
    name: string;

    /// Currency code e.g. USD, CAD, etc
    code: string;

    /// Currency image url
    imageUrl?: string;

    /// The number of decimals the currency contains
    decimals: number;

    /// The blockchain this currency belongs to
    blockchain: string;

    /// The market capital of this coin
    marketCap: number;
}

/// Convert this `CryptoCurrencyEntryDTO` to a `CryptoCurrency` model, if possible
///
/// - Parameters:
///     - sortIndex: The sort index to use within the database once persisted
///
/// - Returns: A `CryptoCurrency` object, if successful
export function asCryptoCurrency(self: CryptoCurrencyEntryDTO, sortIndex: bigint): CryptoCurrency {
    return new CryptoCurrency(
        new CurrencyCode(self.code),
          self.name,
          BigInt(self.decimals),
          new Blockchain(self.blockchain),
          sortIndex,
          self.imageUrl
        );
}
