import { CurrencyCode } from '@blockchains/models/CurrencyCode';
import { filterNullish } from '@core/extensions/Array';
import { ExchangeRate } from '@wallets/models/ExchangeRate';
import Decimal from 'decimal.js';

export interface GetCryptoExchangeRatesDTO {
  rates: Map<string, GetCryptoPriceDTO>;
}
export interface GetCryptoPriceDTO {
  price: Decimal;
  symbol: string;
  name: string;
  contractAddress?: string;
}

export function cryptoExchangeRatesDTOToExchangeRates(
  response: GetCryptoExchangeRatesDTO,
  chainId?: bigint
): ExchangeRate[] {
  const responseRates = new Map(Object.entries(response.rates));

  return filterNullish(
    [...responseRates.values()].map(rate => {
      const code = rate.symbol.toLocaleUpperCase('en-US');
      const isUSDC = code === CurrencyCode.USDC.rawValue;
      const isETH = code === CurrencyCode.ETH.rawValue;
      const adjustedPrice = new Decimal(isUSDC ? 1 : rate.price);

      if (adjustedPrice.greaterThan(0)) {
        return new ExchangeRate(
          new CurrencyCode(code),
          adjustedPrice,
          rate.contractAddress,
          isETH || rate.contractAddress !== undefined ? chainId : undefined,
          rate.name
        );
      } else {
        return undefined;
      }
    })
  );
}
