import { CurrencyCode } from '@blockchains/models/CurrencyCode';
import { Decimal } from 'decimal.js';

export const schema = '[id],id,currencyCodeStr';
export class ExchangeRate {
  id: string;
  currencyCodeStr: string;
  rateStr: string;
  contractAddress?: string;
  chainId?: bigint;
  name?: string;

  constructor(
    currencyCode: CurrencyCode,
    rate: Decimal,
    contractAddress?: string,
    chainId?: bigint,
    name?: string
  ) {
    this.id = `${currencyCode.rawValue}/${contractAddress}/${chainId}`;
    this.currencyCodeStr = currencyCode.rawValue;
    this.rateStr = rate.toString();
    this.contractAddress = contractAddress;
    this.chainId = chainId;
    this.name = name ?? currencyCode.rawValue.toLocaleUpperCase('en-US');
  }

  get currencyCode(): CurrencyCode {
    return new CurrencyCode(this.currencyCodeStr);
  }

  get rate(): Decimal {
    return new Decimal(this.rateStr);
  }

  set rate(v: Decimal) {
    this.rateStr = v.toString();
  }

  copy(): ExchangeRate {
    return new ExchangeRate(
      this.currencyCode,
      this.rate,
      this.contractAddress,
      this.chainId,
      this.name
    );
  }
}
