import { unwrap } from '@core/extensions/Observable+Core';
import { Startable } from '@core/interfaces/Startable';
import { Store } from '@store/Store';
import { FiatCurrency } from '@wallets/models/FiatCurrency';
import { Observable } from 'rxjs';
import { StoreKeys_activeCurrency } from '../extensions/StoreKeys+Wallets'

export class FiatCurrencyRepository implements Startable {
  store: Store;
  activeCurrencyObservable: Observable<FiatCurrency>;

  constructor(store: Store) {
    this.store = store;
    this.activeCurrencyObservable = this.store
      .observe<FiatCurrency | undefined>(StoreKeys_activeCurrency)
      .pipe(unwrap<FiatCurrency>());
  }

  get activeCurrency(): FiatCurrency {
    return this.store.get(StoreKeys_activeCurrency) ?? FiatCurrency.USD
  }

  start(): Observable<void> {
    return new Observable(observer => {
      if (this.store.get(StoreKeys_activeCurrency) == null) {
        this.store.set(StoreKeys_activeCurrency, FiatCurrency.USD)
      }
      observer.complete()
    })
  }
}
