import * as React from 'react';
import * as ReactDOM from 'react-dom';
import { sendEvent } from './init/analytics';
import { EVENTS } from './init/events';
import { googleAnalytics } from './init/googleAnalytics';

// I18N
import { IntlProvider } from 'react-intl';
import { getLocale, importMessages, LocaleMessages } from './util/i18n';

// CDS

import '@cbhq/cds-web/globalStyles';
import { ThemeProvider } from '@cbhq/cds-web/system/ThemeProvider';

import { Welcome } from './components/welcome/Welcome';

googleAnalytics.push(['_trackPageview']);

const WelcomeWrapper = () => {
  const locale = getLocale();
  const [messages, setMessages] = React.useState<LocaleMessages | null>(null);

  const isDarkMode = false;
  // Uncomment in case of emergency
  // const isDarkMode = window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches;

  React.useEffect(() => {
    importMessages(locale).then(setMessages);
  }, []);

  if (!messages) {
    return null;
  }

  return (
    <React.StrictMode>
      <ThemeProvider scale="large" spectrum={isDarkMode ? 'dark' : undefined}>
        <IntlProvider locale={locale} messages={messages}>
          <Welcome />
        </IntlProvider>
      </ThemeProvider>
    </React.StrictMode>
  );
};

const mountNode = document.getElementById('root');
ReactDOM.render(
  <WelcomeWrapper />,
  mountNode
);

// Log analytics event
sendEvent(EVENTS.INSTALLED);
