import React from 'react';
import ReactDOM from 'react-dom';

// I18N
import { IntlProvider } from 'react-intl';
import { getLocale, importMessages, LocaleMessages } from './util/i18n';

// Google Analytics
import { googleAnalytics } from './init/googleAnalytics';

// Bugsnag
import { bugsnagErrorReporter } from './init/bugsnag';
import { ErrorBoundary } from './components/error/ErrorBoundary';
import { setErrorHandler } from './init/reportError';

// CDS
import '@cbhq/cds-web/globalStyles';
import { ThemeProvider } from '@cbhq/cds-web/system/ThemeProvider';

// Extension box style
import './extension.css';

import App from './App';

const AppWrapper = () => {
  const locale = getLocale();
  const [messages, setMessages] = React.useState<LocaleMessages | null>(null);

  const isDarkMode = false;
  // Uncomment in case of emergency
  // const isDarkMode = window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches;

  React.useEffect(() => {
    importMessages(locale).then(setMessages);

    // We change the root background color programmatically as the CDS ThemeProvider isn't applied on the root level
    const rootBackgroundColor = isDarkMode ? '#000000' : '#FFFFFF';
    document.documentElement.setAttribute('style', `background-color: ${rootBackgroundColor}`);
  }, []);

  if (!messages) {
    return null;
  }

  return (
    <React.StrictMode>
      <ThemeProvider scale="large" spectrum={isDarkMode ? 'dark' : undefined}>
        <IntlProvider locale={locale} messages={messages}>
          <ErrorBoundary>
            <App />
          </ErrorBoundary>
        </IntlProvider>
      </ThemeProvider>
    </React.StrictMode>
  );
};

setErrorHandler(bugsnagErrorReporter);
googleAnalytics.push(['_trackPageview']);
const mountNode = document.getElementById('root');
ReactDOM.render(<AppWrapper />, mountNode);
