import bugsnag from '@bugsnag/js';
import { Event, BrowserConfig } from '@bugsnag/js/types';
import BugsnagPluginReact from '@bugsnag/plugin-react';
import { createErrorReporter } from './reportError';
const APP_VERSION = process.env.NODE_ENV === 'production' ? 'production' : 'local';

const config: BrowserConfig = {
  apiKey: process.env.BUGSNAG_API_KEY || '',
  endpoints: {
    notify: process.env.BUGSNAG_ENDPOINT || '',
    sessions: process.env.BUGSNAG_SESSIONS_ENDPOINT || '',
  },

  appVersion: APP_VERSION,
  releaseStage: process.env.RELEASE_ENVIRONMENT,
  enabledReleaseStages: ['production', 'local', 'development'],
  autoTrackSessions: false,
  enabledBreadcrumbTypes: ['error', 'log', 'navigation', 'request', 'user'],
  plugins: [new BugsnagPluginReact()],
  onError: function (event) {
    event.errors[0].stacktrace = event.errors[0].stacktrace.map(function (frame) {
      frame.file = frame.file.replace(/chrome-extension:/g, 'chrome_extension:');
      return frame;
    });
  },
};

export const bugsnagClient = bugsnag.start(config);

export const setUserId = (userId : string) => {
  bugsnagClient.setUser(userId);
}

export const bugsnagErrorReporter = createErrorReporter((errorData, errorHash) => {
  const { error, errorInfo, metadata, context, severity } = errorData;

  const onError = (bugsnagError: Event) => {
    bugsnagError.context = context;

    bugsnagError.severity = severity || 'error';

    bugsnagError.addMetadata('custom', { ...metadata, errorHash, ...errorInfo });
  };
  bugsnagClient.notify(error, onError);
});
