import {
  WalletLinkUI,
  WalletLinkUIOptions,
} from '../../node_modules/walletlink/build/npm/dist/provider/WalletLinkUI';
import log from '../util/log';
import { Pubsub, ParentRequestEthereumAccounts, ReloadParentRequestEthereumAccounts } from '../util/Pubsub';
import { ServiceWorkerStorageKeys } from './ServiceWorkerStorageKeys';
export interface SessionState {
  version: string;
  _id: string;
  _secret: string;
  walletLinkUrl: string;
  isOpen: boolean;
  _linked: boolean;
  valid: boolean;
  onCancel: () => void;
}

export class WalletLinkExtensionUI extends WalletLinkUI {
  private _nextRequestId = 0;
  private cancelLinkCallbacks = new Map<string, () => void>();

  constructor(private options: Readonly<WalletLinkUIOptions>) {
    super(options);
    log('In constructor of WalletLinkExtensionUI');
  }

  attach(): void {}

  requestEthereumAccounts(options: { onCancel: () => void }): void {
    //Let the service worker know that parent is currently disconnected
    chrome.storage.local.set({ [ServiceWorkerStorageKeys.parentConnected]: false });

    Pubsub.next(
      new ParentRequestEthereumAccounts(
        this.options.walletLinkUrl,
        this.options.session.id,
        this.options.session.secret,
        this.options.version
      )
    );
  }

  hideRequestEthereumAccounts(): void {
    //No op for the extension
  }

  showConnecting(options: { onCancel: () => void; onResetConnection: () => void }): () => void {
    //No-op for the extension so far
    return () => {};
  }

  // Called when the extension is disconnected.
  reloadUI(): void {
    Pubsub.next(new ReloadParentRequestEthereumAccounts())
  }

  inlineAccountsResponse(): boolean {
    return false;
  }

  public makeCancelLinkRequestId(): string {
    // max nextId == max int32 for compatibility with mobile
    this._nextRequestId = (this._nextRequestId + 1) % 0x7fffffff;
    const id = this._nextRequestId;
    const idStr = id.toString(16);
    // unlikely that this will ever be an issue, but just to be safe
    const callback = this.cancelLinkCallbacks.get(idStr);
    if (callback) {
      // TODO - how to handle this case
      this.cancelLinkCallbacks.delete(idStr);
    }
    return idStr;
  }
}
