import * as sourceOfTruth from '../i18n/en.json';
export type LocaleMessages = typeof sourceOfTruth;

export function importMessages(locale: string): Promise<LocaleMessages> {
  // Each supported locale will require a "case" to pick up the correct import
  switch (locale) {
    case 'en':
      return import('../i18n/en.json');
    default:
      return import('../i18n/en.json');
  }
}

/*
 * Get the locale from the user's query parameters, if they exist.
 * If the 'lang' query parameter is not present, try to find one from their
 * browser preference, and finally fallback to English
 */
export const getLocale = (): string => {
  let locale = new URLSearchParams(window.location.search).get('lang');
  if (!locale) {
    locale = normalizedLocale() || 'en';
  }
  return locale;
};

/*
 * Gets the locale from the browser.
 * Browser might return a locale that is too specific for us,
 * so we will normalize it to a more generic locale.
 * (i.e. "en-US" and "en-GB" are just "en" for us)
 */
export const normalizedLocale = (): string => {
  let locale;

  if (chrome) {
    // Check extension UI language
    locale = chrome.i18n.getUILanguage();
  } else if (navigator?.languages?.length) {
    // Chrome and Firefox supply an array
    locale = navigator.languages[0];
  } else {
    // Safari only gives one locale
    locale = navigator.language;
  }

  return locale ? locale.toLowerCase().split(/[_-]+/)[0] || 'en' : 'en';
};
