// Copyright (c) 2018-2020 WalletLink.org <https://www.walletlink.org/>
// Copyright (c) 2018-2020 Coinbase, Inc. <https://www.coinbase.com/>
// Licensed under the Apache License, version 2.0

package util

import (
	"testing"
	"time"

	"github.com/stretchr/testify/require"
)

func TestMemoryCache(t *testing.T) {
	mc := NewMemoryCache()

	require.Nil(t, mc.Get("key"))
	mc.Set("key", "hello")
	require.Equal(t, mc.Get("key"), "hello")

	mc.Set("expired-key", "hello", 10*time.Millisecond)
	require.Equal(t, mc.Get("expired-key"), "hello")

	time.Sleep(11 * time.Millisecond)

	require.Nil(t, mc.Get("expired-key"), nil)
}

func TestMemoryCacheHouseKeeping(t *testing.T) {
	mc := NewMemoryCache()

	mc.Set("key", "hello")
	mc.Set("expired-key", "hello", 10*time.Millisecond)
	require.Equal(t, mc.Len(), 2)

	time.Sleep(11 * time.Millisecond)
	mc.HouseKeeping()

	require.Equal(t, mc.Len(), 1)
	require.Equal(t, mc.Get("key"), "hello")
	require.Nil(t, mc.Get("expired-key"), nil)
}
